@@ -1,4 +1,4 @@
-/* gnome program that crashes
+/* gtk program that crashes
  *
  * Copyright (C) Jacob Berkman
  *
@@ -19,20 +19,17 @@
  */
 
 #include "config.h"
-
-#include <libgnome/gnome-program.h>
-#include <libgnomeui/gnome-client.h>
-#include <libgnomeui/gnome-ui-init.h>
+#include <gtk/gtk.h>
 
 int
 main (int argc, char *argv[])
 {
 	int *n = NULL;
-	gnome_program_init ("Crashing GNOME Program", VERSION,
-			    LIBGNOMEUI_MODULE,
-			    argc, argv,
-			    GNOME_CLIENT_PARAM_SM_CONNECT, FALSE,
-			    NULL);
+
+	gtk_init (&argc, &argv);
+	/* test the log handler */
+	g_critical ("ka-boom!");
+
 	n[27] = 10-7-78;
 	return 0;
 }
